render

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 21, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func PrintDependency

func PrintDependency(report inspector.DependencyReport, writer io.Writer) error

PrintDependency writes the import dependency-graph report.

func PrintDuplication

func PrintDuplication(report inspector.DuplicationReport, writer io.Writer) error

PrintDuplication writes the duplicate-code report.

func PrintSummary

func PrintSummary(summary inspector.Summary, writer io.Writer) error

PrintSummary writes a ranked, aggregate view designed to surface the highest value places to improve.

func PrintTree

func PrintTree(root *inspector.TreeNode, writer io.Writer) error

PrintTree writes the analyzed directory tree to the provided writer.

Types

This section is empty.

Jump to